CONSTRUCT_STAGES = {
    "building": {
        "id": "building",
        "name": "Строительство",
        "iconName": "check",
        "color": "#24C9FF",
        "order": 1
    },
    "acceptance": {
        "id": "acceptance",
        "name": "Приёмка",
        "iconName": "internal-acceptance",
        "color": "#FF8B05",
        "order": 2
    },
    "transfer": {
        "id": "transfer",
        "name": "Передача",
        "iconName": "owner-acceptance",
        "color": "#0ED78C",
        "order": 3
    },
    "warranty": {
        "id": "warranty",
        "name": "Гарантия",
        "iconName": "warranty-claim",
        "color": "#5C66F0",
        "order": 4
    }
}